% camera3D(c,orientation,size)
% 
%   camera3D generate a 3D wireframe of a stylized camera, to represent
%   the direction of the point of view. ON the camera there is a frame wich
%   shows the 3 axis
% 
% 
%     x axes = freen
%     y axes = blue
%     z axes = red
% 
% _________________________________________________________________________
% 
% -I/O
% 
%   Given:
% 
%      c        [3 x 1 double] Camera centre. It may be evaluated from the
%                              [Rt] matrix, by calculating -R'*t
%             
%      rotmat   [3 x 3 double] Camera orientation. IT may be generate from
%                              the [Rt] by transposing (R')
% 
%      size     [1 x 1 double] A constant wich represent the size of 
%                              the camera.
% _________________________________________________________________________
% 
%   the call:
% 
%      camera3D(c,orientation,size)
% 
%   returns:
% 
%      Camera wireframe oriented in the world reference frame
% 
% -Examples
% 
%    camera3D([0 0 0]',eye(3,3),10)
% ________________________________________________________________________
% Created by Cosimo Rubino
% Last Modified: 03/10/2013



function camera3D(c,orient,size,color)

if nargin<4
    color=[0 0 1];
end

% Points of the cube
C_points1 =[1 1 1 1 0 0 0 0; ...
            1 1 0 0 1 1 0 0; ...
            1 0 1 0 1 0 1 0 ];

% Points of the trapezioid
C_points2 =[.75  1  .75;
            .25  1  .75;
            .25  1  .25;
            .75  1  .25;
            1    2  1;
            1    2  0;
            0    2  1;
            0    2  0;
            ]';
 
 % Join of the cube and the trapezoid
 Cam.points  = [C_points1 C_points2];
 Cam.points  = Cam.points + repmat([-.5 -1 -.5]',1,length(Cam.points));
 Cam.points  = [1 0 0; 0 0 -1; 0 1 0]*Cam.points;
 
%  Apply the rotations and the traslation to the camera wireframe
 Cam.points  = size.*orient*Cam.points + repmat(c',1,length(Cam.points));
 
 % Point to generate the wireframe lines
 lines     = [1 2 4 3 7 8 6 5 1 2 6 5 7 8 4 3 1  9 10 11 12 14 16 14 13 9 13 15 10 15 16 11 16 11 12 9 1 ;
              2 4 3 7 8 6 5 1 2 6 5 7 8 4 3 1 9 10 11 12 14 16 14 13 9 13 15 10 15 16 11 16 11 12 9  1 2];
 
 % Plot of the camera 
 plot3([Cam.points(1,lines(1,:)) Cam.points(1,lines(2,:))],...
       [Cam.points(2,lines(1,:)) Cam.points(2,lines(2,:))],...
       [Cam.points(3,lines(1,:)) Cam.points(3,lines(2,:))],'-k','linewidth',1.5,'color',color);
   
 hold on;
%  frame_repr(c',size.*orient);
 axis equal;
          
 