function [ AP ] = ellipsoidOverlap( Q1, Q2, niter )
%ellipseOverlap finds the overlapping volume between two ellipsoids, and
%returns the Average Precision AP.
% Q1 and Q2 are two matrices associated to two dual quadrics (inverse of matrices associated to quadrics)
% 
%   The Average Precision of two areas means:
% 
%           volume_intersection
%   AP  = ------------------------
%              volume_union
%   
Q1      = -Q1/Q1(4,4);
Q1      = -Q1/sign(Q1(1,1));
Q2      = -Q2/Q2(4,4);
Q2      = -Q2/sign(Q2(1,1));

bbx1    = ellpid2bbx(Q1,4);
bbx2    = ellpid2bbx(Q2,4); 

bbxEnvelope = ([min([bbx2(1),bbx1(1)]),min([bbx2(2),bbx1(2)]),min([bbx2(3),bbx1(3)]),max([bbx2(4),bbx1(4)]),max([bbx2(5),bbx1(5)]),max([bbx2(6),bbx1(6)])]);


% Volume of the bounding boxes

xNorm   = [rand(3,niter);ones(1,niter)];

x      = bbxEnvelope(1:3)'*ones(1,niter) + xNorm(1:3,:).*([abs(bbxEnvelope(4)-bbxEnvelope(1));abs(bbxEnvelope(5)-bbxEnvelope(2));abs(bbxEnvelope(6)-bbxEnvelope(3))]*ones(1,niter));
x      = [x; ones(1,niter)];

% Linearized form
Lx = [x(1,:).*x(1,:);x(1,:).*x(2,:);x(1,:).*x(3,:);x(1,:);x(2,:).*x(2,:);x(2,:).*x(3,:);x(2,:);x(3,:).*x(3,:);x(3,:);ones(1,size(x(2,:),2))];
LC1 = [Q1(1,1),2*Q1(2,1),2*Q1(3,1),2*Q1(4,1),Q1(2,2),2*Q1(3,2),2*Q1(4,2),Q1(3,3),2*Q1(4,3),Q1(4,4)]';
LC2 = [Q2(1,1),2*Q2(2,1),2*Q2(3,1),2*Q2(4,1),Q2(2,2),2*Q2(3,2),2*Q2(4,2),Q2(3,3),2*Q2(4,3),Q2(4,4)]';

isIn1       = (LC1'*Lx)>=0;
isIn2       = (LC2'*Lx)>=0;
intz         = logical(isIn1.*isIn2);

AP = sum(intz)/sum(isIn1+isIn2-intz);

end

function [ BBx ] = ellpid2bbx( Q )
%ell2bbx gives out the bounding box of the ellipsoid.
%   Detailed explanation goes here

% % Find the two tangent of the ellipse along x

BBx(1) =  (Q(4,1) + sqrt(Q(4,1) ^ 2 - Q(4,4) * Q(1,1)))  / Q(4,4);
BBx(4) = -(-Q(4,1) + sqrt(Q(4,1) ^ 2 - Q(4,4) * Q(1,1))) / Q(4,4);

BBx(2) =  (Q(4,2) + sqrt(Q(4,2) ^ 2 - Q(4,4) * Q(2,2)))  / Q(4,4);
BBx(5) = -(-Q(4,2) + sqrt(Q(4,2) ^ 2 - Q(4,4) * Q(2,2))) / Q(4,4);

BBx(3) =   (Q(4,3) + sqrt(Q(4,3) ^ 2 - Q(4,4) * Q(3,3))) / Q(4,4);
BBx(6) = -(-Q(4,3) + sqrt(Q(4,3) ^ 2 - Q(4,4) * Q(3,3))) / Q(4,4);

BBx = [min([BBx(1),BBx(4)]),min([BBx(2),BBx(5)]),min([BBx(3),BBx(6)]),...
       max([BBx(1),BBx(4)]),max([BBx(2),BBx(5)]),max([BBx(3),BBx(6)])];
   
end

