function [ C ] = fromBBx2ell( bbx, frVw )
%FROMBBX2ELL convert a Bounding Box matrix to another matrix which includes
% all the dual cubics related to the ellipses associated to each bounding box.
% 
%SYNTAX
% 
%   [ C ] = fromBBx2ell( bbx, frVw )
% 
%INPUTS
% 
% bbx   [F x 4O]:  Matrix of the bounding boxes
% frVw  [F x  O]:  Matrix of the views which are considered for a given 
%                  viewpoint
% 
%OUTPUT
% 
% C     [3Fx 3O]:  Matrix of the cubics related to the bounding boxes
%
%   See also ELL2BBX, ELLPID2BBX, PLOTELLIPSE, PLOTELLIPSOID,
%   ELLIPSOIDOVERLAP, FROMELLGT2BBX, FROMBBX2ELLOR

C = zeros(size(bbx,1)*3,3*size(bbx,2)/4);

for o=1:size(bbx,2)/4
    for f=find(frVw(:,o))'
        C(f*3-2:f*3,3*o-2:3*o)  = bbx2ell(bbx(f,4*o-3:4*o),'in');
    end
end

end

