function [ Rec ] = generateQuadrics( P, x3c, C, frVw, recMethod )
%GENERATEQUADRICS is a function which generates quadrics starting from the
% motion matrices, the calibration matrix and the ellipses matrix.
%
%SYNTAX
% 
% [ Q ] = generateQuadrics( P, x3c, C, frVw )
% 
%INPUT
% 
% P     : is the projective matrix associated to the camera
% frVw  : is the logical matrix which has 1 if the object o is present in a
%         certain frame, and 0 if it is not present
% C 	: is the matrix of the dual conics

n_o                 = size(frVw,2);

% Condition for number of views less than three
nOfWvTot            = sum(frVw,1);
objSeq              = find(nOfWvTot>2);
Rec                 = cell(1,n_o);

% Evaluate ellipsoid associated to each object

for o=objSeq
    
    % Ellipses belonging to the frames indicated by the ones in the frVw
    % matrix
    Cvw = C(logical(kron(frVw(:,o),true(3,1))),3*o-2:3*o);
    
    % Motion matrices belonging to the frames indicated by the ones in the 
    % frVw matrix
    
    Pvw = P(logical(kron(frVw(:,o),[1 1 1 1]')),:);
    
    traslMx = [eye(3),x3c(1:3,o);0 0 0 1];
    Pvw_t   = zeros(size(Pvw,1),size(Pvw,2));

    for f=1:sum(frVw(:,o))
       Pvw_t(4*f-3:4*f,1:3) = ([eye(3),zeros(3,1)]*([Pvw(4*f-3:4*f,:)';0 0 0 1]*traslMx))';
    end

    switch recMethod
        case 'SFD'
            Qadj = recEllipsoid( Pvw_t, Cvw);
        case 'NEWREG'
            Qadj = newRegF( Pvw_t, Cvw, 'persp');
    end
    
    Qadj = traslMx*Qadj*traslMx';
    
    % Reinforce symmetry
    Qadj = 0.5*(Qadj + Qadj');
    Rec{o}.Q    = Qadj/-Qadj(4,4);
end

