function plot2Dscene( Im, bbx, Cnt, Cr )
%PLOT2DSCENE includes the routine to plot the 2D frames given all the data
%associated to the measurements on the video sequence
% 
%SYNTAX
% 
% plot2Dscene( Im, R, S, T, W, rwOk, bbx, Cnt, Cjv, nA, cz, Cr, Nfl )
% 
%INPUT
% 
% Im    [STRUCT F x 1]: Struct containing the images as field I
% P    [DOUBLE 2F x 3]: Matrix containing all the 3x4 perspective camera
%                       matrices
% bbx  [DOUBLE Z x 4A]: Matrix containing all the bounding boxes A (without
%                       selection).
% Cnt[DOUBLE 3F x O]  : Matrix containing all the conics associated to
%                       ellipses and points
% Cr     [3F x 3O]    : Conics associated to the reconstructed ellipsoids
% Nfl           [FLAG]: Flag for points plotting P
% 
% Created by MCosimo Rubino
% Last version: 12 december 2016
% 
% See also PLOT2DSCENE.
% 
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

nA = size(Cnt,2)/3;
nF = size(Cnt,1)/3;

scrsz = get(0,'screensize');

figure('name','Input frames and measurements','color','white'); 

frVw = ~isnan(bbx(:,1:4:end));
visF = find(sum(frVw,2)~=0);

for f =visF'
    cla;
    imshow(Im{f}.I); 
    title(['frame ' num2str(f)]); hold on;
   for o = 1 : nA
        if any(Cnt(3*f,3*o))
            plotEllipse(Cnt(3*f-2:3*f,3*o-2:3*o)/(-Cnt(3*f,3*o)),[1 0 0],4); hold on;
            plotEllipse(Cr(3*f-2:3*f,3*o-2:3*o)/-Cr(3*f,3*o),[0 1 0],4);hold on;
            plotBbx(bbx(f,4*o-3:4*o),[1 1 0],2,o); hold on;
        end
   end
   
   set(gcf,'position',[scrsz(3)*.35-500,scrsz(4)*.25,700,500]);
   
   pause(.3);
end

end

