function [ rec, fout ] = plot3Dscene( Rec, S, recClr)
%PLOT3DSCENE generates the 3D plot of the ellipsoid given all the data
%about the scene
% 
%SYNTAX
% 
% [ rec ] = plot3Dscene( Rec, S, O, P, colzero, seq, Npflag)
% 
%INPUT
% 
% Rec   [STRUCT 1 x O]: The structure containing the field Q for each
%                       reconstructed ellipsoid 
% S   [DOUBLE 3 x P]  : Cloud of points (structure) containing the points
%                       extracted from the images P+O and the centers of 
%                       the ellipsoids.
% 
% Created by Cosimo Rubino
% Last version: 12 december 2016
% 
% See also PLOT2DSCENE.
% 
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

scrsz = get(0,'screensize');
Nfl = ~isempty(S);
nA  = length(Rec);

rec = [];

fout = figure('name','3D Reconstruction','color','white','position',[scrsz(3)*.50,scrsz(4)*.25,700,500]);
if nargin<3
    recClr = [0 1 0];
end

for o = 1 : nA
   if isfield(Rec{o},'Q')
       plotEllipsoid(Rec{o}.Q,'none',recClr,[],o);hold on;
       rec{o}.Q = Rec{o}.Q;
   end
end

if Nfl
    hold on;
      plot3(S(1,:),S(2,:),S(3,:),'ob','markersize',5,'MarkerFaceColor',[0 1 0]); 
end

axis on;
grid on;
axis equal;

end

