function C = plotEllipse(Ch, clr, lnwdth,lnTyp)
%PLOTELLIPSE plots an ellipse given the homogeneous cubic form
% 
%SYNTAX
% 
% plotEllipse(C, clr, lnwdth, parent)
% 
%INPUT
%        
%        | c1  c21 c31 |
%   C  = | c21  c2 c32 |
%        | c31 c32 c33 |
% 
% Ch      [3 x 3 DOUBLE]: The conic which represents the ellipse in the
%                         homogeneous form
% clr     [1 x 3 DOUBLE]: The triplet which represents the color in RGB.
% lnwdth  [1 x 1 DOUBLE]: the width of the line in the ellipse plotting.
% parent                : in case of subplots, it returns the subplot where
%                          the ellipse should be plotted.
% 
% See also PLOTELLIPSOID. 

N   = 200;
%Ch  = Ch/sign(Ch(1,1));

if nargin<2
  clr     = [1 0 0];
  lnwdth  = 2;
end
if nargin<3
  lnwdth  = 2;
end

    
[ax, C, R] = explodeparam( Ch );

 if isreal(ax(1)) && isreal(ax(2))
    theta = 0:1/N:2*pi+1/N;
  
  % Parametric equation of the ellipse
    %----------------------------------------
    state(1,:) = ax(1)*cos(theta);
    state(2,:) = ax(2)*sin(theta);
    
    % Coordinate transform 
    %----------------------------------------

    X = R * state;
    X(1,:) = X(1,:) + C(1);
    X(2,:) = X(2,:) + C(2);

    % Plot the ellipse
    %----------------------------------------
    switch nargin
        case 1
            clr     = [1 0 0];
            lnwdth  = 2;
            lnTyp   = '-';
        case 2 
            lnwdth  = 2;
            lnTyp   = '-';
        case 3
            lnTyp   = '-';
    end
    
plot(X(1,:),X(2,:),lnTyp,'Color',clr,'LineWidth',lnwdth);

end

end
