function C = plotEllipsoid(Q, clr, edgclr,s1,oNmb)
%PLOTELLIPSOID plots the ellipsoid given the homogeneous quadric form
% 
%SYNTAX
% 
% plotEllipsoid(Q, clr, edgclr, parent, oNmb)
% 
%INPUT
%        
%        | q1  q21 q31 q14|
%   Q  = | q21 q2  q32 q24|
%        | q31 q32 q3  q34|
%        | q41 q42 q43 q44|
% 
% Ch      [4 x 4 DOUBLE]: The quadric which represents the ellipsoid in the
%                         homogeneous form.
% clr     [1 x 3 DOUBLE]: The triplet which represents the color of the solid in RGB.
% edgclr  [1 x 3 DOUBLE]: The triplet which represents the color of the edges in RGB.
% lnwdth  [1 x 1 DOUBLE]: the width of the line in the ellipse plotting.
% parent                : in case of subplots, it returns the subplot where
%                         the ellipse should be plotted.
% oNmb                  : Attach the number of the object to each ellipsoid
% See also PLOTELLIPSE. 

if nargin<2
   clr     = 'none';
   edgclr  = [1 0 0];
end

% Q           = Q/(-Q(4,4));

C= squeeze(-Q(1:3,4));

T = [1 0 0 -C(1); 0 1 0 -C(2); 0 0 1 -C(3); 0 0 0 1];


Qcent = T*Q*T';

[ V, D ] = eig(Qcent(1:3,1:3));

a = sqrt(abs(D(1,1)));
b = sqrt(abs(D(2,2)));
c = sqrt(abs(D(3,3)));

if (isreal(a) && isreal(b) && isreal(c))
 N = 20; 
     [X,Y,Z] = ellipsoid(0,0,0,a,b,c,N);
    %  rotate and center the ellipsoid to the actual center point
    %------------------------------------------------------------
    XX = zeros(N+1,N+1);
    YY = zeros(N+1,N+1);
    ZZ = zeros(N+1,N+1);
    for k = 1:length(X),
        for j = 1:length(X),
            point = [X(k,j) Y(k,j) Z(k,j)]';
            P = V * point;
            XX(k,j) = P(1)+C(1);
            YY(k,j) = P(2)+C(2);
            ZZ(k,j) = P(3)+C(3);
        end
    end

    % Plot the ellipse
    % ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

    if isempty(s1)
        surface(XX,YY,ZZ,'FaceColor', clr,'EdgeColor', edgclr, 'linewidth', 1, 'EdgeAlpha',0.3);
    else
        surface(XX,YY,ZZ,'FaceColor', clr,'EdgeColor', edgclr,'Parent', s1, 'linewidth', 1, 'EdgeAlpha',0.3);
    end
    axis equal;
    alpha(0.2);
    hold on;

    if nargin == 5
        text(C(1),C(2),C(3),num2str(oNmb),'FontName','Arial','Color',[1 0.3 0],'FontWeight','Bold','FontSize',20);
    end
    axis off
grid off
    hidden off
else
    [xs,ys,zs] = sphere;
    xs = .1*aStar*xs;
    ys = .1*aStar*ys;
    zs = .1*aStar*zs;
    
    hold on;
    plot3(C(1),C(2),C(3),'*','MarkerEdgeColor',edgclr);
    if nargin==5
        text(C(1),C(2),C(3),num2str(oNmb),'FontSize',10);
    end

end
