function [ Qadj ] = recEllipsoid( P, C)
%RECELLIPSOID Reconstruct an ellipsoid given the conics of the
%reprojection matrices
%
%SYNTAX
% 
% [ Qadj ] = RECELLIPSOID( P, C, proj)
% 
%INPUT
% 
% P     : Projection Matrix [4F x 4O]
% C     : Matrix of the conics [3F x 3O]
% proj  : Flag which describes the kind of reconstruction
% K     : Calibration Matrix
% 
% 
%OUTPUT
% 
% Qadj  : Adjoint of the quadric which represents the ellipsoid

views = size(C,1)/3;
% Initialization

M   = zeros(6*views,10+views);

% Get B matrices
for n = 1:views
    
    C0 = C(3*n-2:3*n-1,3);
    %[D1,C0] = cart2homo( C(3*n-2:3*n,1:3) );

    % Centering the ellipses
    
    [ax,~,~] = explodeparam(C(3*n-2:3*n,:));
    divF    = sqrt(sum(ax.^2));
    T       = [divF*eye(2),C0;0 0 1]^(-1);
            
    % Get B matrices ----------------------------
    P_fr   = P(n*4-3:n*4,1:3)*T';
       
    vecP    = Pvectz(P_fr);
    B       = computeB(vecP);
    
    % Get Cdual vectors -------------------------
    C_t    = T*C(3*n-2:3*n,1:3)*T';    
    C_tv   = sym2vec(C_t);
    C_tv   = C_tv/-C_tv(end);
    
    M(6*n-5:6*n,1:10) = B;
    M(6*n-5:6*n,10+n) = -C_tv;

end

fprintf('\n Reconstruction method: SVD \n');
[~,~,V] = svd(M);
w       = V(:,end);
Qadjv   = w(1:10);
Qadj    = vec2sym(Qadjv);

end

