function [ C ] = reprQ(P,A,frVw,repr)
%REPRQ Generates all the ellipses given an ellipsoid described by a 
% quadric
% 
%SYNTAX
% 
% [ C ] = reprQ(M,K,GT,frVw)
% 
%INPUTS
% 
% P  [4F x 3 DOUBLE]: Projective matrix of the cameras
% A     [1 x O CELL]: Cell which contains the information about the Reconstruction
% frVw [F x O LOGIC]: Matrix which indicates which object is visible inside
%                     each frame
% 
%OUTPUT
% 
% C        [3F x 3O]: Matrix which contains all the dual conics (ellipses) in each frame
% 
%   See also ELL2BBX, ELLPID2BBX, PLOTELLIPSE, PLOTELLIPSOID, ELLIPSOIDOVERLAP.

C = zeros(3*size(frVw,1),3*size(frVw,2));

for o=find(sum(frVw)~=0)
    if ~isempty(A{o})
            for f=find(frVw(:,o))'
                if strcmp(repr,'persp')
                    projM = P(4*f-3:4*f,:)';
                elseif strcmp(repr,'ortho');
                    projM = [P(4*f-3:4*f-2,:)'; 0 0 0 1];
                end
                CtempDual = projM*A{o}.Q*projM';
                CtempDual = CtempDual/abs(CtempDual(3,3));
                C(f*3-2:f*3,3*o-2:3*o) = CtempDual;
            end
    end
end

end
