clear all 
close all
clc

cd /home/crubino/Desktop/code
addpath(genpath('./functions'));

% ~~~~~~ Demo data ~~~~~~~~~~~~~~~~~
% Sequence 7 of the TUW dataset
load('data/seq7_TUW.mat');

% Data needed:
% bbx   [F x 4O]:  Matrix of the bounding boxes
% frVw  [F x  O]:  Matrix of the views which are considered for a given 
%                  viewpoint
% Imm   [F]     :  Struct of the images I
% K     [3 x 3] :  Camera calibration matrix
% GT    [O]     :  Struct of the GT dual quadrics
% M     [4F x 3]:  Matrix of the motion

%% ~~~~~~~~~~~~~~~~~~ Compute the centres ~~~~~~~~~~~~~~~~~~~~~~
% First step of computing the elliposoids (to reduce ill-posedness of quadrics)

% Compute the projective matrix given the motion matrix 
% (if you have already the projective matrix, skip this step)
P = (K*M')';

% Fit the ellipses to the bounding boxes
C   = fromBBx2ell(bbx,frVw);

% Convert the GT from primal to dual
GT = gtconv(GT);

% Compute the centers
x3c0 = [0 0 0 1]'*ones(1,size(frVw,2));

% Compute the reconstructions (dual quadrics)
Rec1 = generateQuadrics(P, x3c0, C, frVw, 'SFD' );

% Compute the reprojections of the reconstruction (dual ellipses)
Crec = reprQ(P,Rec1,frVw,'persp');

% Compute the reprojections of the Ground Truth dual ellipsoids
Cgt  = reprQ(P,GT,frVw,'persp');

%% ~~~~~~~~~~~~~~~~~~ Compute the centres ~~~~~~~~~~~~~~~~~~~~~~
% Second step: Re-computing the ellipsoids given the centres

% Compute the centres given the first reconstruction
x3c1 = exCnt(Rec1);

% Compute the reconstructions (dual quadrics)
Rec2 = generateQuadrics(P, x3c1, C, frVw, 'SFD' );

% Compute the reprojections (dual ellipses)
Crec = reprQ(P,Rec2,frVw,'persp');

% Plot the 2D ellipses
plot2Dscene( Imm, bbx, C, Crec );

% Plot the 3D scene given the dual ellipsoids
rec = plot3Dscene( Rec2, [], [0 1 0]);

